
### Added
- New `orchestration_status` handler for querying orchestration run progress

### Fixed
- Support `view_config_external_id` shorthand in orchestrator handler
- Simplify settings loading in orchestrator